@@ -281,16 +281,16 @@ test_that("verbose testing", {
 
   x <- sparse_character("A", 1, 1)
   expect_snapshot({
-    tmp <- x[]
-    tmp <- x[]
+    tmp <- sparse_string_materialize(x)
+    tmp <- sparse_string_materialize(x)
   })
 
   withr::local_options("sparsevctrs.verbose_materialize" = 2)
 
   x <- sparse_character("A", 1, 1)
   expect_snapshot({
-    tmp <- x[]
-    tmp <- x[]
+    tmp <- sparse_string_materialize(x)
+    tmp <- sparse_string_materialize(x)
   })
 
   withr::local_options("sparsevctrs.verbose_materialize" = 3)
@@ -299,7 +299,7 @@ test_that("verbose testing", {
   expect_snapshot(
     error = TRUE,
     {
-      tmp <- x[]
+      tmp <- sparse_string_materialize(x)
     }
   )
 })
