@@ -452,16 +452,16 @@ test_that("verbose testing", {
 
   x <- sparse_integer(1, 1, 1)
   expect_snapshot({
-    tmp <- x[]
-    tmp <- x[]
+    tmp <- sparse_integer_materialize(x)
+    tmp <- sparse_integer_materialize(x)
   })
 
   withr::local_options("sparsevctrs.verbose_materialize" = 2)
 
   x <- sparse_integer(1, 1, 1)
   expect_snapshot({
-    tmp <- x[]
-    tmp <- x[]
+    tmp <- sparse_integer_materialize(x)
+    tmp <- sparse_integer_materialize(x)
   })
 
   withr::local_options("sparsevctrs.verbose_materialize" = 3)
@@ -470,7 +470,7 @@ test_that("verbose testing", {
   expect_snapshot(
     error = TRUE,
     {
-      tmp <- x[]
+      tmp <- sparse_integer_materialize(x)
     }
   )
 })
